@@ -15,7 +15,6 @@ import os
 from oslo_utils import uuidutils
 import requests
 import requests.auth
-import six
 from tempest.lib import exceptions
 
 from aodhclient.tests.functional import base
@@ -289,7 +288,7 @@ class AodhClientTest(base.ClientTestBase):
         def test(params):
             result = self.aodh('alarm', params=params)
             alarm = self.details_multiple(result)[0]
-            for key, value in six.iteritems(expected_lines):
+            for key, value in expected_lines.items():
                 self.assertEqual(value, alarm[key])
             return alarm
 
@@ -392,7 +391,7 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
 
         req = requests.post(
             os.environ.get("GNOCCHI_ENDPOINT") + "/v1/resource/generic",
-            auth=requests.auth.HTTPBasicAuth('admin', ''),
+            headers={"X-Auth-Token": self.get_token()},
             json={
                 "id": RESOURCE_ID,
             })
@@ -574,8 +573,6 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
 
     def test_gnocchi_aggr_by_resources_scenario(self):
 
-        PROJECT_ID = uuidutils.generate_uuid()
-
         # CREATE
         result = self.aodh(
             u'alarm',
@@ -586,14 +583,13 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
                     "--query "
                     '\'{"=": {"creator": "cr3at0r"}}\' '
                     "--resource-type generic "
-                    "--aggregation-method last "
-                    "--project-id %s" % PROJECT_ID))
+                    "--aggregation-method mean "))
         alarm = self.details_multiple(result)[0]
         ALARM_ID = alarm['alarm_id']
         self.assertEqual('alarm1', alarm['name'])
         self.assertEqual('cpu', alarm['metric'])
         self.assertEqual('80.0', alarm['threshold'])
-        self.assertEqual('last', alarm['aggregation_method'])
+        self.assertEqual('mean', alarm['aggregation_method'])
         self.assertEqual('generic', alarm['resource_type'])
         self.assertEqual('{"=": {"creator": "cr3at0r"}}',
                          alarm['query'])
@@ -609,8 +605,7 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
                     "--query "
                     '\'{"=": {"creator": "cr3at0r"}}\' '
                     "--resource-type generic "
-                    "--aggregation-method last "
-                    "--project-id %s" % PROJECT_ID))
+                    "--aggregation-method mean "))
 
         # UPDATE
         result = self.aodh(
@@ -626,12 +621,11 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
             'alarm', params="show %s" % ALARM_ID)
         alarm_show = self.details_multiple(result)[0]
         self.assertEqual(ALARM_ID, alarm_show["alarm_id"])
-        self.assertEqual(PROJECT_ID, alarm_show["project_id"])
         self.assertEqual('alarm1', alarm_show['name'])
         self.assertEqual('cpu', alarm_show['metric'])
         self.assertEqual('90.0', alarm_show['threshold'])
         self.assertEqual('critical', alarm_show['severity'])
-        self.assertEqual('last', alarm_show['aggregation_method'])
+        self.assertEqual('mean', alarm_show['aggregation_method'])
         self.assertEqual('generic', alarm_show['resource_type'])
 
         # LIST
@@ -686,7 +680,7 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
         alarm = self.details_multiple(result)[0]
         ALARM_ID = alarm['alarm_id']
         self.assertEqual('alarm1', alarm['name'])
-        metrics = "[u'cpu', u'cpu_util']" if six.PY2 else "['cpu', 'cpu_util']"
+        metrics = "['cpu', 'cpu_util']"
         self.assertEqual(metrics, alarm['metrics'])
         self.assertEqual('80.0', alarm['threshold'])
         self.assertEqual('last', alarm['aggregation_method'])
@@ -793,13 +787,13 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
                              "--query "
                              '\'{"=": {"creator": "cr3at0r"}}\' '
                              "--resource-type generic "
-                             "--aggregation-method last "
+                             "--aggregation-method mean "
                              % ALARM_ID))
         alarm_updated = self.details_multiple(result)[0]
         self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
         self.assertEqual('cpu', alarm_updated['metric'])
         self.assertEqual('90.0', alarm_updated['threshold'])
-        self.assertEqual('last', alarm_updated['aggregation_method'])
+        self.assertEqual('mean', alarm_updated['aggregation_method'])
         self.assertEqual('generic', alarm_updated['resource_type'])
         self.assertEqual('{"=": {"creator": "cr3at0r"}}',
                          alarm_updated['query'])
@@ -843,13 +837,13 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
                     "--query "
                     '\'{"=": {"creator": "cr3at0r"}}\' '
                     "--resource-type generic "
-                    "--aggregation-method last "))
+                    "--aggregation-method mean "))
         alarm = self.details_multiple(result)[0]
         ALARM_ID = alarm['alarm_id']
         self.assertEqual('alarm123', alarm['name'])
         self.assertEqual('cpu', alarm['metric'])
         self.assertEqual('80.0', alarm['threshold'])
-        self.assertEqual('last', alarm['aggregation_method'])
+        self.assertEqual('mean', alarm['aggregation_method'])
         self.assertEqual('generic', alarm['resource_type'])
         self.assertEqual('{"=": {"creator": "cr3at0r"}}',
                          alarm['query'])
@@ -865,7 +859,7 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
                              % (ALARM_ID, METRIC1, METRIC2)))
         alarm_updated = self.details_multiple(result)[0]
         self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
-        metrics = "[u'cpu', u'cpu_util']" if six.PY2 else "['cpu', 'cpu_util']"
+        metrics = "['cpu', 'cpu_util']"
         self.assertEqual(metrics, alarm_updated['metrics'])
         self.assertEqual('80.0', alarm_updated['threshold'])
         self.assertEqual('last', alarm_updated['aggregation_method'])
@@ -880,13 +874,13 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
                              "--query "
                              '\'{"=": {"creator": "cr3at0r"}}\' '
                              "--resource-type generic "
-                             "--aggregation-method last "
+                             "--aggregation-method mean "
                              % ALARM_ID))
         alarm_updated = self.details_multiple(result)[0]
         self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
         self.assertEqual('cpu', alarm_updated['metric'])
         self.assertEqual('80.0', alarm_updated['threshold'])
-        self.assertEqual('last', alarm_updated['aggregation_method'])
+        self.assertEqual('mean', alarm_updated['aggregation_method'])
         self.assertEqual('generic', alarm_updated['resource_type'])
         self.assertEqual('{"=": {"creator": "cr3at0r"}}',
                          alarm_updated['query'])
@@ -896,3 +890,192 @@ class AodhClientGnocchiRulesTest(base.ClientTestBase):
         # DELETE
         result = self.aodh('alarm', params="delete %s" % ALARM_ID)
         self.assertEqual("", result)
+
+
+class AodhClientPrometheusRulesTest(base.ClientTestBase):
+
+    def test_prometheus_type_scenario(self):
+
+        QUERY = "ceilometer_image_size"
+
+        req = requests.get(
+            os.environ.get("PROMETHEUS_ENDPOINT") +
+            "/api/v1/status/runtimeinfo",
+        )
+        self.assertEqual(200, req.status_code)
+
+        # CREATE
+        result = self.aodh(u'alarm',
+                           params=(u"create "
+                                   "--type prometheus "
+                                   "--name alarm_p1 "
+                                   "--threshold 80 "
+                                   "--query %s "
+                                   % QUERY))
+        alarm = self.details_multiple(result)[0]
+        ALARM_ID = alarm['alarm_id']
+        self.assertEqual('alarm_p1', alarm['name'])
+        self.assertEqual(QUERY, alarm['query'])
+        self.assertEqual('80.0', alarm['threshold'])
+
+        # CREATE WITH --TIME-CONSTRAINT
+        result = self.aodh(
+            u'alarm',
+            params=(u"create --type prometheus "
+                    "--name alarm_ptc --threshold 80 "
+                    "--time-constraint "
+                    "name=cons1;start='0 11 * * *';duration=300 "
+                    "--time-constraint "
+                    "name=cons2;start='0 23 * * *';duration=600 "
+                    "--query %s "
+                    % QUERY))
+        alarm = self.details_multiple(result)[0]
+        alarm_ptc_id = alarm["alarm_id"]
+        self.assertEqual('alarm_ptc', alarm['name'])
+        self.assertEqual('80.0', alarm['threshold'])
+        self.assertIsNotNone(alarm['time_constraints'])
+
+        # CREATE FAIL MISSING PARAM
+        self.assertRaises(exceptions.CommandFailed,
+                          self.aodh, u'alarm',
+                          params=(u"create "
+                                  "--type prometheus "
+                                  "--name alarm1 "
+                                  "--query %s "
+                                  % QUERY))
+
+        # UPDATE
+        result = self.aodh(
+            'alarm', params=("update %s --severity critical --threshold 90"
+                             % ALARM_ID))
+        alarm_updated = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_updated["alarm_id"])
+        self.assertEqual('critical', alarm_updated['severity'])
+        self.assertEqual('90.0', alarm_updated["threshold"])
+
+        # GET
+        result = self.aodh(
+            'alarm', params="show %s" % ALARM_ID)
+        alarm_show = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_show["alarm_id"])
+        self.assertEqual('alarm_p1', alarm_show['name'])
+        self.assertEqual('90.0', alarm_show['threshold'])
+        self.assertEqual('critical', alarm_show['severity'])
+        self.assertEqual(QUERY, alarm_show['query'])
+
+        # GET BY NAME
+        result = self.aodh(
+            'alarm', params="show --name alarm_p1")
+        alarm_show = self.details_multiple(result)[0]
+        self.assertEqual(ALARM_ID, alarm_show["alarm_id"])
+        self.assertEqual('alarm_p1', alarm_show['name'])
+        self.assertEqual('90.0', alarm_show['threshold'])
+        self.assertEqual('critical', alarm_show['severity'])
+        self.assertEqual(QUERY, alarm_show['query'])
+
+        # GET BY NAME AND ID ERROR
+        self.assertRaises(exceptions.CommandFailed,
+                          self.aodh, u'alarm',
+                          params=(u"show %s --name alarm_p1" %
+                                  ALARM_ID))
+
+        # LIST
+        result = self.aodh('alarm', params="list --filter all_projects=true")
+        self.assertIn(ALARM_ID,
+                      [r['alarm_id'] for r in self.parser.listing(result)])
+        output_colums = ['alarm_id', 'type', 'name', 'state', 'severity',
+                         'enabled']
+        for alarm_list in self.parser.listing(result):
+            self.assertEqual(sorted(output_colums), sorted(alarm_list.keys()))
+            if alarm_list["alarm_id"] == ALARM_ID:
+                self.assertEqual('alarm_p1', alarm_list['name'])
+
+        # LIST WITH PAGINATION
+        # list with limit
+        result = self.aodh('alarm',
+                           params="list --filter all_projects=true --limit 1")
+        alarm_list = self.parser.listing(result)
+        self.assertEqual(1, len(alarm_list))
+        # list with sort with key=name dir=asc
+        result = self.aodh(
+            'alarm',
+            params="list --filter all_projects=true --sort name:asc")
+        names = [r['name'] for r in self.parser.listing(result)]
+        sorted_name = sorted(names)
+        self.assertEqual(sorted_name, names)
+        # list with sort with key=name dir=asc and key=alarm_id dir=asc
+        result = self.aodh(
+            u'alarm',
+            params=(u"create --type prometheus "
+                    "--name alarm_p2 --threshold 80 "
+                    "--query %s"
+                    % QUERY))
+        created_alarm_id = self.details_multiple(result)[0]['alarm_id']
+        result = self.aodh(
+            'alarm',
+            params="list --filter all_projects=true --sort name:asc "
+                   "--sort alarm_id:asc")
+        alarm_list = self.parser.listing(result)
+        ids_with_same_name = []
+        names = []
+        for alarm in alarm_list:
+            names.append(['alarm_name'])
+            if alarm['name'] == 'alarm_p2':
+                ids_with_same_name.append(alarm['alarm_id'])
+        sorted_ids = sorted(ids_with_same_name)
+        sorted_names = sorted(names)
+        self.assertEqual(sorted_names, names)
+        self.assertEqual(sorted_ids, ids_with_same_name)
+        # List with sort with key=name dir=desc and with the marker
+        # verify that we handle non full and empty pages correctly.
+        # Verify that marker works as expected
+
+        # We have 3 alarms. List the first 2.
+        result = self.aodh(
+            'alarm',
+            params="list --filter all_projects=true --filter "
+                   "type=prometheus --sort name:asc --limit 2")
+        alarm_list = self.parser.listing(result)
+        self.assertNotIn('alarm_ptc',
+                         [r['name'] for r in alarm_list])
+        self.assertEqual(2, len(alarm_list))
+
+        # List the next page. Only the 3rd alarm should be returned
+        result = self.aodh(
+            'alarm',
+            params="list --filter all_projects=true --filter "
+                   "type=prometheus --sort name:asc "
+                   "--marker %s --limit 2" % alarm_list[1]['alarm_id'])
+        alarm_list = self.parser.listing(result)
+        self.assertIn('alarm_ptc',
+                      [r['name'] for r in alarm_list])
+        self.assertEqual(1, len(alarm_list))
+
+        # List the next page. Empty page should be returned
+        result = self.aodh(
+            'alarm',
+            params="list --filter all_projects=true --filter "
+                   "type=prometheus --sort name:asc "
+                   "--marker %s --limit 2" % alarm_list[0]['alarm_id'])
+        alarm_list = self.parser.listing(result)
+        self.assertEqual(0, len(alarm_list))
+
+        # Delete the last created alarm
+        self.aodh('alarm', params="delete %s" % created_alarm_id)
+        # Delete alarm_ptc
+        self.aodh('alarm', params="delete %s" % alarm_ptc_id)
+
+        # DELETE
+        result = self.aodh('alarm', params="delete %s" % ALARM_ID)
+        self.assertEqual("", result)
+
+        # GET FAIL
+        result = self.aodh('alarm', params="show %s" % ALARM_ID,
+                           fail_ok=True, merge_stderr=True)
+        expected = "Alarm %s not found (HTTP 404)" % ALARM_ID
+        self.assertFirstLineStartsWith(result.splitlines(), expected)
+
+        # DELETE FAIL
+        result = self.aodh('alarm', params="delete %s" % ALARM_ID,
+                           fail_ok=True, merge_stderr=True)
+        self.assertFirstLineStartsWith(result.splitlines(), expected)
